# Data Acknowledgements  
The datasets and images used as example for this project come from a variety of places. To the best of my knowledge, they are all open source. If I'm wrong about that, please let me know! Thank you to all the original authors of the data and images! Here are links to the original sources:     
  
1. [2019_53_WA_Counties9467365124727016.json](https://catalog.data.gov/dataset/tiger-line-shapefile-2019-state-washington-current-county-subdivision-state-based)

2. [colony.csv](https://github.com/rfordatascience/tidytuesday/blob/main/data/2022/2022-01-11/readme.md)    
   
3. [sales_final_dataset.csv](https://github.com/sql-bi/Contoso-Data-Generator-V2-data/releases/tag/ready-to-use-data) and [here](https://workout-wednesday.com/pbi-2025-w13/)    

4. [examples/data/Taipei_skyline_at_sunset_20150607.jpg](https://commons.wikimedia.org/wiki/File:Taipei_skyline_at_sunset_20150607.jpg)

5. [wa_bigfoot_by_county.csv](https://www.bfro.net/) and [here](https://github.com/Russell-Shean/bigfoot_sightings/tree/main/data)